#ifndef FUNCTIONS_H
#define FUNCTIONS_H


#include <vector>
#include <string>
#include <Eigen/Dense>

using namespace std;

// Helper function to convert string to number
template <typename T>
T convertTo(const std::string &str) {
    std::istringstream ss(str);
    T num;
    ss >> num;
    return num;
}

class Functions
{
public:
    Functions();
    static std::vector<std::string> splitWithStl(const std::string &str,const std::string &pattern);
    static double FitCenterByLeastSquares(std::vector<Eigen::Vector2d> mapPoint);
    static Eigen::Vector2d interpolate_translation(double t1,
                                            Eigen::Vector2d trans1,
                                            double t2,
                                            Eigen::Vector2d trans2,
                                            double t_inter);
    static double interpolate_heading(double t1,double heading1,double t2,double heading2, double t_inter);

    static Eigen::Vector2d gcs2vcs(Eigen::Vector2d gcs_p, Eigen::Vector2d cen_p, double heading);
    static Eigen::Vector2d vcs2gcs(Eigen::Vector2d host_p, float vh, Eigen::Vector2d vcs_p);

    bool IsThreePointsInLine(const Eigen::Vector2d &p1, const Eigen::Vector2d &p2,
                             const Eigen::Vector2d &p3, double radian_deviation);

    static double GetTwoVectorsAngle(const Eigen::Vector2d &v1,
                              const Eigen::Vector2d &v2);

};

#endif // FUNCTIONS_H
